@@ -32,7 +32,7 @@
 class MediaPlayer2Player : public QDBusAbstractAdaptor
 {
     Q_OBJECT
-    Q_CLASSINFO("D-Bus Interface", "org.mpris.MediaPlayer2.Player") // Docs: http://www.mpris.org/2.1/spec/Player_Node.html
+    Q_CLASSINFO("D-Bus Interface", "org.mpris.MediaPlayer2.Player") // Docs: https://specifications.freedesktop.org/mpris-spec/latest/Media_Player.html
 
     Q_PROPERTY(QString PlaybackStatus READ PlaybackStatus)
     Q_PROPERTY(QString LoopStatus READ LoopStatus WRITE setLoopStatus)
