@@ -167,6 +167,8 @@ PlaylistBox::PlaylistBox(PlayerManager *player, QWidget *parent, QStackedWidget
             this, SLOT(slotSetHistoryPlaylistEnabled(bool)));
 
     m_showTimer = new QTimer(this);
+    m_showTimer->setSingleShot(true);
+    m_showTimer->setInterval(500);
     connect(m_showTimer, SIGNAL(timeout()), SLOT(slotShowDropTarget()));
 
     // hook up to the D-Bus
@@ -473,12 +475,7 @@ void PlaylistBox::slotSavePlaylists()
 
 void PlaylistBox::slotShowDropTarget()
 {
-    if(!m_dropItem) {
-        qCCritical(JUK_LOG) << "Trying to show the playlist of a null item!\n";
-        return;
-    }
-
-    raise(m_dropItem->playlist());
+    if(m_dropItem) raise(m_dropItem->playlist());
 }
 
 void PlaylistBox::slotAddItem(const QString &tag, unsigned column)
@@ -543,6 +540,24 @@ void PlaylistBox::setSingleItem(QTreeWidgetItem *item)
     setSelectionMode(QAbstractItemView::ExtendedSelection);
 }
 
+void PlaylistBox::dragMoveEvent(QDragMoveEvent* event)
+{
+    QTreeWidget::dragMoveEvent(event);
+
+    Item* hovered_item = static_cast<Item*>(itemAt(event->pos()));
+    if(hovered_item != m_dropItem){
+        m_dropItem = hovered_item;
+        if(m_dropItem) m_showTimer->start();
+        else m_showTimer->stop();
+    };
+}
+
+void PlaylistBox::dragLeaveEvent(QDragLeaveEvent* event)
+{
+    QTreeWidget::dragLeaveEvent(event);
+    m_showTimer->stop();
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // PlaylistBox private slots
 ////////////////////////////////////////////////////////////////////////////////
@@ -694,7 +709,6 @@ PlaylistBox::Item *PlaylistBox::Item::m_collectionItem = 0;
 
 PlaylistBox::Item::Item(PlaylistBox *listBox, const QString &icon, const QString &text, Playlist *l)
     : QObject(listBox), QTreeWidgetItem(listBox, QStringList(text)),
-      PlaylistObserver(l),
       m_playlist(l), m_iconName(icon), m_sortedFirst(false)
 {
     init();
@@ -702,7 +716,6 @@ PlaylistBox::Item::Item(PlaylistBox *listBox, const QString &icon, const QString
 
 PlaylistBox::Item::Item(Item *parent, const QString &icon, const QString &text, Playlist *l)
     : QObject(parent->listView()), QTreeWidgetItem(parent, QStringList(text)),
-    PlaylistObserver(l),
     m_playlist(l), m_iconName(icon), m_sortedFirst(false)
 {
     init();
@@ -713,13 +726,6 @@ PlaylistBox::Item::~Item()
 
 }
 
-// FIXME paintcell
-/*void PlaylistBox::Item::paintCell(QPainter *painter, const QColorGroup &colorGroup, int column, int width, int align)
-{
-    PlaylistBox *playlistBox = static_cast<PlaylistBox *>(listView());
-    playlistBox->viewMode()->paintCell(this, painter, colorGroup, column, width, align);
-}*/
-
 void PlaylistBox::Item::setup()
 {
     listView()->viewMode()->setupItem(this);
@@ -736,15 +742,9 @@ void PlaylistBox::Item::slotSetName(const QString &name)
     setSelected(true);
 
     treeWidget()->scrollToItem(this);
-    //FIXME viewmode
-    //listView()->viewMode()->queueRefresh();
 }
 
-void PlaylistBox::Item::playingItemHasChanged()
-{
-}
-
-void PlaylistBox::Item::playlistItemDataHasChanged()
+void PlaylistBox::Item::playlistItemDataChanged()
 {
     // This avoids spuriously re-saving all playlists just because play queue
     // changes.
@@ -783,6 +783,8 @@ void PlaylistBox::Item::init()
         m_sortedFirst = true;
 
     setText(1, sortTextFor(itemText));
+
+    connect(&(m_playlist->signaller), &PlaylistInterfaceSignaller::playingItemDataChanged, this, &PlaylistBox::Item::playlistItemDataChanged);
 }
 
 QString PlaylistBox::Item::sortTextFor(const QString &name) const
