@@ -109,6 +109,8 @@ private:
     void setupUpcomingPlaylist();
     int viewModeIndex() const { return m_viewModeIndex; }
     ViewMode *viewMode() const { return m_viewModes[m_viewModeIndex]; }
+    void dragMoveEvent(QDragMoveEvent *event) override;
+    void dragLeaveEvent(QDragLeaveEvent *event) override;
 
 private slots:
     /**
@@ -142,7 +144,7 @@ private:
     QTimer *m_savePlaylistTimer;
 };
 
-class PlaylistBox::Item final : public QObject, public QTreeWidgetItem, public PlaylistObserver
+class PlaylistBox::Item final : public QObject, public QTreeWidgetItem
 {
     friend class PlaylistBox;
     friend class PlaylistSplitter;
@@ -171,22 +173,12 @@ protected:
     QString text() const { return QTreeWidgetItem::text(0); }
     void setSortedFirst(bool first = true) { m_sortedFirst = first; }
 
-    /*virtual void paintCell(QPainter *p, const QColorGroup &colorGroup, int column, int width, int align);
-    virtual void paintFocus(QPainter *, const QColorGroup &, const QRect &) {}*/
-
     virtual void setup();
 
     static Item *collectionItem() { return m_collectionItem; }
-    static void setCollectionItem(Item *item) { m_collectionItem = item; }
-
-    //
-    // Reimplemented from PlaylistObserver
-    //
-
-    virtual void playingItemHasChanged() override;
 
     // Used to post a timer in PlaylistBox to save playlists.
-    virtual void playlistItemDataHasChanged() override;
+    void playlistItemDataChanged();
 
 
 protected slots:
