@@ -241,12 +241,12 @@ void PlaylistCollection::showMore(const QString &artist, const QString &album)
         components.append(c);
     }
 
-    PlaylistSearch search(playlists, components, PlaylistSearch::MatchAll);
+    auto search = new PlaylistSearch(playlists, components, PlaylistSearch::MatchAll, object());
 
     if(m_showMorePlaylist)
         m_showMorePlaylist->setPlaylistSearch(search);
     else
-        m_showMorePlaylist = new SearchPlaylist(this, search, i18n("Now Playing"), false, true);
+        m_showMorePlaylist = new SearchPlaylist(this, *search, i18n("Now Playing"), false, true);
 
     // The call to raise() below will end up clearing m_belowShowMorePlaylist,
     // so cache the value we want it to have now.
@@ -455,7 +455,7 @@ void PlaylistCollection::editSearch()
         return;
 
     auto searchDialog = new AdvancedSearchDialog(
-            p->name(), p->playlistSearch(), JuK::JuKInstance());
+            p->name(), *(p->playlistSearch()), JuK::JuKInstance());
     QObject::connect(searchDialog, &QDialog::finished, [searchDialog, p](int result)
             {
                 if (result) {
@@ -532,13 +532,13 @@ void PlaylistCollection::createSearchPlaylist()
     QString name = uniquePlaylistName(i18n("Search Playlist"));
 
     auto searchDialog = new AdvancedSearchDialog(
-            name, PlaylistSearch(), JuK::JuKInstance());
+            name, *(new PlaylistSearch(JuK::JuKInstance())), JuK::JuKInstance());
     QObject::connect(searchDialog, &QDialog::finished, [searchDialog, this](int result)
             {
                 if (result) {
                     raise(new SearchPlaylist(
                                 this,
-                                searchDialog->resultSearch(),
+                                *searchDialog->resultSearch(),
                                 searchDialog->resultPlaylistName()));
                 }
                 searchDialog->deleteLater();
